# Adansonia

_Adansonia_ is a genus of deciduous trees known as baobabs. They are found in arid regions of Madagascar, mainland Africa, Arabia, and Australia. The generic name honours [Michel Adanson](https://fr.wikipedia.org/wiki/Michel_Adanson), the French naturalist and explorer who described Adansonia digitata.